@@ -26,18 +26,18 @@
 int main(int argc, char **argv)
 {
     QCoreApplication app(argc, argv);
-    KAboutData about(QStringLiteral("kdeconnect-cli"),
-                     QStringLiteral("kdeconnect-cli"),
-                     QStringLiteral(KDECONNECT_VERSION_STRING),
-                     i18n("KDE Connect CLI tool"),
-                     KAboutLicense::GPL,
-                     i18n("(C) 2015 Aleix Pol Gonzalez"));
-    KAboutData::setApplicationData(about);
+    KAboutData aboutData(QStringLiteral("kdeconnect-cli"),
+                         QStringLiteral("kdeconnect-cli"),
+                         QStringLiteral(KDECONNECT_VERSION_STRING),
+                         i18n("KDE Connect CLI tool"),
+                         KAboutLicense::GPL,
+                         i18n("© 2015–2025, KDE Connect Team"));
+    aboutData.addAuthor(i18n("Aleix Pol Gonzalez"), {}, QStringLiteral("aleixpol@kde.org"));
+    aboutData.addAuthor(i18n("Albert Vaca Cintora"), {}, QStringLiteral("albertvaka@kde.org"));
+    KAboutData::setApplicationData(aboutData);
 
     KCrash::initialize();
 
-    about.addAuthor(i18n("Aleix Pol Gonzalez"), QString(), QStringLiteral("aleixpol@kde.org"));
-    about.addAuthor(i18n("Albert Vaca Cintora"), QString(), QStringLiteral("albertvaka@gmail.com"));
     QCommandLineParser parser;
     parser.addOption(QCommandLineOption(QStringList{QStringLiteral("l"), QStringLiteral("list-devices")}, i18n("List all devices")));
     parser.addOption(
@@ -66,8 +66,8 @@ int main(int argc, char **argv)
     parser.addOption(QCommandLineOption(QStringLiteral("send-sms"), i18n("Sends an SMS. Requires destination"), i18n("message")));
     parser.addOption(QCommandLineOption(QStringLiteral("destination"), i18n("Phone number to send the message"), i18n("phone number")));
     parser.addOption(QCommandLineOption(QStringLiteral("attachment"),
-                                        i18n("File urls to send attachments with the message (can be passed multiple times)"),
-                                        i18n("file urls")));
+                                        i18n("File URLs to send attachments with the message (can be passed multiple times)"),
+                                        i18n("file URLs")));
     parser.addOption(QCommandLineOption(QStringList{QStringLiteral("device"), QStringLiteral("d")}, i18n("Device ID"), QStringLiteral("dev")));
     parser.addOption(QCommandLineOption(QStringList{QStringLiteral("name"), QStringLiteral("n")}, i18n("Device Name"), QStringLiteral("name")));
     parser.addOption(QCommandLineOption(QStringLiteral("encryption-info"), i18n("Get encryption info about said device")));
@@ -84,10 +84,10 @@ int main(int argc, char **argv)
         QStringLiteral("Outputs all available devices id's with their name and paired status")); // Not visible, so no translation needed
     deviceAutocomplete.setValueName(QStringLiteral("shell"));
     parser.addOption(deviceAutocomplete);
-    about.setupCommandLine(&parser);
+    aboutData.setupCommandLine(&parser);
 
     parser.process(app);
-    about.processCommandLine(&parser);
+    aboutData.processCommandLine(&parser);
 
     DaemonDbusInterface iface;
 
@@ -254,7 +254,7 @@ int main(int argc, char **argv)
             if (!dev.isReachable()) {
                 // Device doesn't exist, go into discovery mode and wait up to 30 seconds for the device to appear
                 QEventLoop wait;
-                QTextStream(stderr) << i18n("waiting for device...") << Qt::endl;
+                QTextStream(stderr) << i18n("waiting for device…") << Qt::endl;
 
                 QObject::connect(&iface, &DaemonDbusInterface::deviceAdded, &iface, [&](const QString &deviceAddedId) {
                     if (device == deviceAddedId) {
