@@ -27,6 +27,14 @@ public:
         return 0;
     }
 
+    void enable() override
+    {
+    }
+
+    void disable() override
+    {
+    }
+
     void onStart() override;
     void onStop() override;
     void onNetworkChange() override;
