@@ -76,6 +76,17 @@ void KdeConnectConfig::setName(const QString &name)
     d->m_config->sync();
 }
 
+void KdeConnectConfig::setDisabledLinkProviders(const QStringList disabledProviders)
+{
+    d->m_config->setValue(QStringLiteral("disabled_providers"), disabledProviders);
+    d->m_config->sync();
+}
+
+QStringList KdeConnectConfig::disabledLinkProviders() const
+{
+    return d->m_config->value(QStringLiteral("disabled_providers")).toStringList();
+}
+
 DeviceType KdeConnectConfig::deviceType()
 {
     const QByteArrayList platforms = qgetenv("PLASMA_PLATFORM").split(':');
@@ -159,6 +170,7 @@ void KdeConnectConfig::addTrustedDevice(const DeviceInfo &deviceInfo)
     d->m_trustedDevices->beginGroup(deviceInfo.id);
     d->m_trustedDevices->setValue(QStringLiteral("name"), deviceInfo.name);
     d->m_trustedDevices->setValue(QStringLiteral("type"), deviceInfo.type.toString());
+    d->m_trustedDevices->setValue(QStringLiteral("protocolVersion"), deviceInfo.protocolVersion);
     QString certString = QString::fromLatin1(deviceInfo.certificate.toPem());
     d->m_trustedDevices->setValue(QStringLiteral("certificate"), certString);
     d->m_trustedDevices->endGroup();
@@ -177,6 +189,7 @@ void KdeConnectConfig::updateTrustedDeviceInfo(const DeviceInfo &deviceInfo)
     d->m_trustedDevices->beginGroup(deviceInfo.id);
     d->m_trustedDevices->setValue(QStringLiteral("name"), deviceInfo.name);
     d->m_trustedDevices->setValue(QStringLiteral("type"), deviceInfo.type.toString());
+    d->m_trustedDevices->setValue(QStringLiteral("protocolVersion"), deviceInfo.protocolVersion);
     d->m_trustedDevices->endGroup();
     d->m_trustedDevices->sync();
 }
@@ -189,6 +202,14 @@ QSslCertificate KdeConnectConfig::getTrustedDeviceCertificate(const QString &id)
     return QSslCertificate(certString.toLatin1());
 }
 
+int KdeConnectConfig::getTrustedDeviceProtocolVersion(const QString &id)
+{
+    d->m_trustedDevices->beginGroup(id);
+    int protocolVersion = d->m_trustedDevices->value(QStringLiteral("protocolVersion"), 0).toInt();
+    d->m_trustedDevices->endGroup();
+    return protocolVersion;
+}
+
 DeviceInfo KdeConnectConfig::getTrustedDevice(const QString &id)
 {
     d->m_trustedDevices->beginGroup(id);
@@ -351,7 +372,7 @@ void KdeConnectConfig::generateCertificate(const QString &certPath)
 {
     qCDebug(KDECONNECT_CORE) << "Generating certificate";
 
-    QString uuid = QUuid::createUuid().toString();
+    QString uuid = QUuid::createUuid().toString(QUuid::Id128).toLower();
     DBusHelper::filterNonExportableCharacters(uuid);
     qCDebug(KDECONNECT_CORE) << "My id:" << uuid;
 
