@@ -12,26 +12,17 @@
 IndicatorHelper::IndicatorHelper()
 {
 }
+
 IndicatorHelper::~IndicatorHelper()
 {
 }
 
-void IndicatorHelper::preInit()
-{
-}
-
-void IndicatorHelper::postInit()
-{
-}
-
 void IndicatorHelper::iconPathHook()
 {
 }
 
-int IndicatorHelper::daemonHook(QProcess &kdeconnectd)
+int IndicatorHelper::startDaemon()
 {
-    Q_UNUSED(kdeconnectd);
-
     return 0;
 }
 
