@@ -31,4 +31,15 @@ void blockOnReply(QDBusPendingReply<void> reply)
     }
 }
 
+template<typename T, typename W>
+static void setWhenAvailable(const QDBusPendingReply<T> &pending, W func, QObject *parent)
+{
+    QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(pending, parent);
+    QObject::connect(watcher, &QDBusPendingCallWatcher::finished, parent, [func](QDBusPendingCallWatcher *watcher) {
+        watcher->deleteLater();
+        QDBusPendingReply<T> reply = *watcher;
+        func(reply.isError(), reply.value());
+    });
+}
+
 #endif
