@@ -22,9 +22,8 @@ K_PLUGIN_CLASS_WITH_JSON(ContactsPlugin, "kdeconnect_contacts.json")
 
 ContactsPlugin::ContactsPlugin(QObject *parent, const QVariantList &args)
     : KdeConnectPlugin(parent, args)
+    , vcardsPath(QString(*vcardsLocation).append(QStringLiteral("/kdeconnect-").append(device()->id())))
 {
-    vcardsPath = QString(*vcardsLocation).append(QStringLiteral("/kdeconnect-").append(device()->id()));
-
     // Register custom types with dbus
     qRegisterMetaType<uID>("uID");
     qDBusRegisterMetaType<uID>();
@@ -45,19 +44,15 @@ void ContactsPlugin::connected()
     synchronizeRemoteWithLocal();
 }
 
-bool ContactsPlugin::receivePacket(const NetworkPacket &np)
+void ContactsPlugin::receivePacket(const NetworkPacket &np)
 {
     // qCDebug(KDECONNECT_PLUGIN_CONTACTS) << "Packet Received for device " << device()->name();
     // qCDebug(KDECONNECT_PLUGIN_CONTACTS) << np.body();
 
     if (np.type() == PACKAGE_TYPE_CONTACTS_RESPONSE_UIDS_TIMESTAMPS) {
-        return handleResponseUIDsTimestamps(np);
+        handleResponseUIDsTimestamps(np);
     } else if (np.type() == PACKET_TYPE_CONTACTS_RESPONSE_VCARDS) {
-        return handleResponseVCards(np);
-    } else {
-        // Is this check necessary?
-        qCDebug(KDECONNECT_PLUGIN_CONTACTS) << "Unknown packet type received from device: " << device()->name() << ". Maybe you need to upgrade KDE Connect?";
-        return false;
+        handleResponseVCards(np);
     }
 }
 
@@ -191,7 +186,8 @@ bool ContactsPlugin::sendRequestWithIDs(const QString &packetType, const uIDList
 
 QString ContactsPlugin::dbusPath() const
 {
-    return QStringLiteral("/modules/kdeconnect/devices/") + device()->id() + QStringLiteral("/contacts");
+    return QLatin1String("/modules/kdeconnect/devices/%1/contacts").arg(device()->id());
 }
 
 #include "contactsplugin.moc"
+#include "moc_contactsplugin.cpp"
