@@ -4,8 +4,7 @@
  * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
-#ifndef WINDOWSREMOTEINPUT_H
-#define WINDOWSREMOTEINPUT_H
+#pragma once
 
 #include "abstractremoteinput.h"
 
@@ -19,5 +18,3 @@ public:
     bool handlePacket(const NetworkPacket &np) override;
     bool hasKeyboardSupport() override;
 };
-
-#endif
