@@ -19,25 +19,12 @@
 
 K_PLUGIN_CLASS_WITH_JSON(PingPlugin, "kdeconnect_ping.json")
 
-PingPlugin::PingPlugin(QObject *parent, const QVariantList &args)
-    : KdeConnectPlugin(parent, args)
-{
-    //     qCDebug(KDECONNECT_PLUGIN_PING) << "Ping plugin constructor for device" << device()->name();
-}
-
-PingPlugin::~PingPlugin()
-{
-    //     qCDebug(KDECONNECT_PLUGIN_PING) << "Ping plugin destructor for device" << device()->name();
-}
-
-bool PingPlugin::receivePacket(const NetworkPacket &np)
+void PingPlugin::receivePacket(const NetworkPacket &np)
 {
     Daemon::instance()->sendSimpleNotification(QStringLiteral("pingReceived"),
                                                device()->name(),
                                                np.get<QString>(QStringLiteral("message"), i18n("Ping!")),
                                                QStringLiteral("dialog-ok"));
-
-    return true;
 }
 
 void PingPlugin::sendPing()
@@ -59,7 +46,8 @@ void PingPlugin::sendPing(const QString &customMessage)
 
 QString PingPlugin::dbusPath() const
 {
-    return QStringLiteral("/modules/kdeconnect/devices/") + device()->id() + QStringLiteral("/ping");
+    return QLatin1String("/modules/kdeconnect/devices/%1/ping").arg(device()->id());
 }
 
+#include "moc_pingplugin.cpp"
 #include "pingplugin.moc"
