@@ -4,8 +4,7 @@
  * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
-#ifndef REMOTECONTROLPLUGIN_H
-#define REMOTECONTROLPLUGIN_H
+#pragma once
 
 #include <QObject>
 
@@ -13,22 +12,16 @@
 
 #define PACKET_TYPE_MOUSEPAD_REQUEST QStringLiteral("kdeconnect.mousepad.request")
 
-class Q_DECL_EXPORT RemoteControlPlugin
-    : public KdeConnectPlugin
+class RemoteControlPlugin : public KdeConnectPlugin
 {
     Q_OBJECT
     Q_CLASSINFO("D-Bus Interface", "org.kde.kdeconnect.device.remotecontrol")
 
 public:
-    explicit RemoteControlPlugin(QObject* parent, const QVariantList &args);
-    ~RemoteControlPlugin() override;
+    using KdeConnectPlugin::KdeConnectPlugin;
 
-    bool receivePacket(const NetworkPacket& /*np*/) override { return false; }
-    void connected() override {}
     QString dbusPath() const override;
 
     Q_SCRIPTABLE void moveCursor(const QPoint &p);
-    Q_SCRIPTABLE void sendCommand(const QVariantMap& body);
+    Q_SCRIPTABLE void sendCommand(const QVariantMap &body);
 };
-
-#endif
