@@ -4,8 +4,7 @@
  * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
-#ifndef SYSTEMVOLUMEPLUGINPULSE_H
-#define SYSTEMVOLUMEPLUGINPULSE_H
+#pragma once
 
 #include <QMap>
 #include <QObject>
@@ -17,19 +16,17 @@
 #define PACKET_TYPE_SYSTEMVOLUME QStringLiteral("kdeconnect.systemvolume")
 #define PACKET_TYPE_SYSTEMVOLUME_REQUEST QStringLiteral("kdeconnect.systemvolume.request")
 
-class Q_DECL_EXPORT SystemvolumePlugin : public KdeConnectPlugin
+class SystemvolumePlugin : public KdeConnectPlugin
 {
     Q_OBJECT
 
 public:
     explicit SystemvolumePlugin(QObject *parent, const QVariantList &args);
 
-    bool receivePacket(const NetworkPacket &np) override;
+    void receivePacket(const NetworkPacket &np) override;
     void connected() override;
 
 private:
     void sendSinkList();
     QMap<QString, PulseAudioQt::Sink *> sinksMap;
 };
-
-#endif
