@@ -5,8 +5,7 @@
  * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
-#ifndef TELEPHONYPLUGIN_H
-#define TELEPHONYPLUGIN_H
+#pragma once
 
 #include <QPointer>
 
@@ -36,13 +35,9 @@ class TelephonyPlugin : public KdeConnectPlugin
     Q_CLASSINFO("D-Bus Interface", "org.kde.kdeconnect.device.telephony")
 
 public:
-    explicit TelephonyPlugin(QObject *parent, const QVariantList &args);
-    ~TelephonyPlugin() override = default;
+    using KdeConnectPlugin::KdeConnectPlugin;
 
-    bool receivePacket(const NetworkPacket &np) override;
-    void connected() override
-    {
-    }
+    void receivePacket(const NetworkPacket &np) override;
     QString dbusPath() const override;
 
 public:
@@ -62,5 +57,3 @@ private:
 
     QPointer<KNotification> m_currentCallNotification;
 };
-
-#endif
