@@ -8,9 +8,9 @@
 #ifndef CONVERSATIONSSORTFILTERPROXYMODEL_H
 #define CONVERSATIONSSORTFILTERPROXYMODEL_H
 
-#include <QSortFilterProxyModel>
 #include <QLoggingCategory>
 #include <QQmlParserStatus>
+#include <QSortFilterProxyModel>
 
 Q_DECLARE_LOGGING_CATEGORY(KDECONNECT_SMS_CONVERSATIONS_SORT_FILTER_PROXY_MODEL)
 
@@ -20,16 +20,22 @@ class ConversationsSortFilterProxyModel : public QSortFilterProxyModel, public Q
     Q_INTERFACES(QQmlParserStatus)
     Q_PROPERTY(Qt::SortOrder sortOrder READ sortOrder WRITE setSortOrder)
 public:
-
-    Qt::SortOrder sortOrder() const { return m_sortOrder; }
-    void setSortOrder(Qt::SortOrder sortOrder) {
+    Qt::SortOrder sortOrder() const
+    {
+        return m_sortOrder;
+    }
+    void setSortOrder(Qt::SortOrder sortOrder)
+    {
         if (m_sortOrder != sortOrder) {
             m_sortOrder = sortOrder;
             sortNow();
         }
     }
-    void classBegin() override {}
-    void componentComplete() override {
+    void classBegin() override
+    {
+    }
+    void componentComplete() override
+    {
         m_completed = true;
         sortNow();
     }
@@ -40,17 +46,18 @@ public:
      * This method gets name of conversations or contact if it find any matching address
      * Needed to check if the conversation or contact already exist or no before adding an arbitrary contact
      */
-    Q_INVOKABLE bool doesAddressExists(const QString& address);
+    Q_INVOKABLE bool doesAddressExists(const QString &address);
 
     ConversationsSortFilterProxyModel();
     ~ConversationsSortFilterProxyModel() override;
 
 protected:
-    bool lessThan(const QModelIndex& leftIndex, const QModelIndex& rightIndex) const override;
+    bool lessThan(const QModelIndex &leftIndex, const QModelIndex &rightIndex) const override;
     bool filterAcceptsRow(int source_row, const QModelIndex &source_parent) const override;
 
 private:
-    void sortNow() {
+    void sortNow()
+    {
         if (m_completed && dynamicSortFilter())
             sort(0, m_sortOrder);
     }
