@@ -50,15 +50,15 @@ int main(int argc, char *argv[])
                          i18n("KDE Connect SMS"),
                          QStringLiteral(KDECONNECT_VERSION_STRING),
                          i18n("SMS Instant Messaging"),
-                         KAboutLicense::GPL_V3,
-                         i18n("(C) 2018-2022, KDE Connect Team"));
+                         KAboutLicense::GPL,
+                         i18n("© 2018–2025 KDE Connect Team"));
     aboutData.addAuthor(i18n("Simon Redman"), {}, QStringLiteral("simon@ergotech.com"));
     aboutData.addAuthor(i18n("Aleix Pol Gonzalez"), {}, QStringLiteral("aleixpol@kde.org"));
     aboutData.addAuthor(i18n("Nicolas Fella"), {}, QStringLiteral("nicolas.fella@gmx.de"));
     aboutData.setBugAddress(QStringLiteral("https://bugs.kde.org/enter_bug.cgi?product=kdeconnect&component=messaging-application").toUtf8());
     KAboutData::setApplicationData(aboutData);
 
-#ifdef Q_OS_WIN
+#if defined(Q_OS_WIN) || defined(Q_OS_MAC)
     // Ensure we have a suitable color theme set for light/dark mode. KColorSchemeManager implicitly applies
     // a suitable default theme.
     KColorSchemeManager::instance();
